@@ -112,6 +112,7 @@ def cmd_build(args):
     use_gpu = getattr(args, "gpu", False)
     registry = getattr(args, "registry", None)
     base_image = getattr(args, "base_image", None)
+    pyversion = getattr(args, "pyversion", None)
 
     version_desc = "GPU版本" if use_gpu else "CPU版本"
     print(f"🚀 开始构建Docker镜像 ({version_desc})...")
@@ -122,7 +123,7 @@ def cmd_build(args):
         builder = DockerBuilder()
 
         image_name, image_id = builder.build_image(
-            args.path, use_gpu, registry, base_image
+            args.path, use_gpu, registry, base_image, pyversion
         )
 
         print(f"\n🎉 镜像构建成功!")
@@ -494,6 +495,7 @@ def cmd_deploy(args):
         use_gpu = getattr(args, "gpu", False)
         registry = getattr(args, "registry", None)
         base_image = getattr(args, "base_image", None)
+        pyversion = getattr(args, "pyversion", None)
 
         version_desc = "GPU版本" if use_gpu else "CPU版本"
         print(f"🚀 开始部署流程 ({version_desc})...")
@@ -501,7 +503,7 @@ def cmd_deploy(args):
         # 构建镜像
         builder = DockerBuilder()
         image_name, _image_id = builder.build_image(
-            args.path, use_gpu, registry, base_image
+            args.path, use_gpu, registry, base_image, pyversion
         )
         print(f"✅ 镜像构建成功: {image_name}")
         print("🌍 地理空间支持已启用 (rasterio/GDAL)")
@@ -553,15 +555,17 @@ def main():
   inoyb serve --dev --open       # 开发模式，自动打开浏览器
   inoyb build                    # 构建Docker镜像 (CPU版本，包含rasterio/GDAL)
   inoyb build --gpu              # 构建GPU版本镜像 (包含rasterio/GDAL+CUDA)
+  inoyb build --pyversion 3.10   # 指定Python 3.10版本构建
   inoyb run <镜像名>             # 运行Docker镜像
-  
+
   # 镜像源配置
   inoyb build --registry registry.cn-hangzhou.aliyuncs.com/library  # 使用阿里云
   inoyb build --base-image my-registry.com/python:3.12-slim         # 自定义镜像
-  
-  inoyb push                     # 推送最新镜像  
+
+  inoyb push                     # 推送最新镜像
   inoyb deploy                   # 一键构建并推送 (CPU版本)
   inoyb deploy --gpu             # 一键构建并推送 (GPU版本)
+  inoyb deploy --pyversion 3.11  # 使用Python 3.11部署
   
   # 运行命令示例
   inoyb run inoyb/my-model:abc123                    # 基本运行
@@ -662,6 +666,9 @@ def main():
     build_parser.add_argument(
         "--base-image", help="完整的基础镜像名 (如: my-registry.com/python:3.12-slim)"
     )
+    build_parser.add_argument(
+        "--pyversion", help="指定Python版本 (如: 3.10, 3.11)，不指定则使用基础镜像默认版本"
+    )
     build_parser.set_defaults(func=cmd_build)
 
     # push命令
@@ -729,6 +736,9 @@ def main():
     deploy_parser.add_argument(
         "--base-image", help="完整的基础镜像名 (如: my-registry.com/python:3.12-slim)"
     )
+    deploy_parser.add_argument(
+        "--pyversion", help="指定Python版本 (如: 3.10, 3.11)，不指定则使用基础镜像默认版本"
+    )
     deploy_parser.set_defaults(func=cmd_deploy)
 
     # 解析参数
