@@ -44,22 +44,32 @@ class DockerBuilder:
         image_uuid = uuid.uuid4().hex[:8]
         return f"{clean_name}:{image_uuid}"
 
+    # def get_miniconda3_version(self) -> str:
+    #     """获取当前 Python 版本对应的 Miniforge3 基础镜像（基于 Debian 12，兼容 rasterio/GDAL）"""
+    #     major, minor = sys.version_info.major, sys.version_info.minor
 
-def get_miniconda3_version(self) -> str:
-    """获取当前 Python 版本对应的 Miniforge3 基础镜像（基于 Debian 12，兼容 rasterio/GDAL）"""
-    major, minor = sys.version_info.major, sys.version_info.minor
+    #     version_map = {
+    #         (3, 8): "condaforge/miniforge3:25.3.1-0",
+    #         (3, 9): "condaforge/miniforge3:25.3.1-0",
+    #         (3, 10): "condaforge/miniforge3:25.3.1-0",
+    #         (3, 11): "condaforge/miniforge3:25.3.1-0",
+    #         (3, 12): "condaforge/miniforge3:25.3.1-0",
+    #         (3, 13): "condaforge/miniforge3:25.3.1-0",
+    #     }
 
-    version_map = {
-        (3, 8): "condaforge/miniforge3:25.3.1-0",
-        (3, 9): "condaforge/miniforge3:25.3.1-0",
-        (3, 10): "condaforge/miniforge3:25.3.1-0",
-        (3, 11): "condaforge/miniforge3:25.3.1-0",
-        (3, 12): "condaforge/miniforge3:25.3.1-0",
-        (3, 13): "condaforge/miniforge3:25.3.1-0",
-    }
+    #     # 如果不是以上版本，默认使用这个镜像
+    #     return version_map.get((major, minor), "condaforge/miniforge3:25.3.1-0")
 
-    # 如果不是以上版本，默认使用这个镜像
-    return version_map.get((major, minor), "condaforge/miniforge3:25.3.1-0")
+    def get_base_image(self) -> str:
+        """获取 micromamba 基础镜像
+
+        使用轻量级 micromamba 镜像（~50MB），Python 版本通过 micromamba install 指定。
+
+        注意：micromamba 镜像仅在 Docker Hub 官方源可用。
+        如配置了镜像加速但拉取失败，请尝试：
+        inoyb build --base-image mambaorg/micromamba:2.1.0-debian12-slim
+        """
+        return "mambaorg/micromamba:2.1.0-debian12-slim"
 
     # def get_miniconda3_version(self) -> str:
     #     """获取当前miniconda3版本对应的Docker基础镜像"""
@@ -150,10 +160,11 @@ def get_miniconda3_version(self) -> str:
         use_gpu: bool = False,
         registry: str = None,
         base_image_override: str = None,
+        python_version: str = None,
     ) -> str:
         """从模板生成Dockerfile内容"""
         # 获取基础镜像名
-        original_base_image = self.get_miniconda3_version()
+        original_base_image = self.get_base_image()
 
         # 解析最终的基础镜像地址（包含项目配置）
         resolved_base_image = self.config.resolve_base_image_with_project(
@@ -164,11 +175,22 @@ def get_miniconda3_version(self) -> str:
         )
 
         examples_copy = (
-            "COPY --chown=$APP_USER:$APP_USER examples/ ./examples/"
+            "COPY --chown=$APP_USER_UID:$APP_USER_GID examples/ ./examples/"
             if has_examples
             else ""
         )
 
+        # 确定使用的Python版本
+        if python_version:
+            # 用户指定了Python版本
+            target_python = python_version
+            logger.info(f"🐍 Python版本: {python_version} (用户指定)")
+        else:
+            # 使用当前系统的 Python 版本作为默认值
+            major, minor = sys.version_info.major, sys.version_info.minor
+            target_python = f"{major}.{minor}"
+            logger.info(f"🐍 Python版本: {target_python} (系统默认)")
+
         # 日志输出
         if resolved_base_image != original_base_image:
             logger.info(f"📦 基础镜像: {original_base_image} -> {resolved_base_image}")
@@ -186,7 +208,9 @@ def get_miniconda3_version(self) -> str:
         # 替换模板变量
         try:
             dockerfile_content = template_content.format(
-                base_image=resolved_base_image, examples_copy=examples_copy
+                base_image=resolved_base_image,
+                python_version=target_python,
+                examples_copy=examples_copy,
             )
         except KeyError as e:
             raise Exception(f"Dockerfile模板变量错误: {e}")
@@ -297,9 +321,12 @@ def get_miniconda3_version(self) -> str:
         use_gpu: bool = False,
         registry: str = None,
         base_image: str = None,
+        python_version: str = None,
     ) -> tuple[str, str]:
         """构建Docker镜像 - 带重试机制的包装器"""
-        return self._build_image_with_retry(project_path, use_gpu, registry, base_image)
+        return self._build_image_with_retry(
+            project_path, use_gpu, registry, base_image, python_version
+        )
 
     def _build_image_with_retry(
         self,
@@ -307,13 +334,14 @@ def get_miniconda3_version(self) -> str:
         use_gpu: bool = False,
         registry: str = None,
         base_image: str = None,
+        python_version: str = None,
         max_retries: int = 3,
     ) -> tuple[str, str]:
         """带重试机制的镜像构建"""
         for attempt in range(max_retries):
             try:
                 return self._build_image_internal(
-                    project_path, use_gpu, registry, base_image
+                    project_path, use_gpu, registry, base_image, python_version
                 )
             except Exception as e:
                 error_msg = str(e)
@@ -503,6 +531,7 @@ def get_miniconda3_version(self) -> str:
         use_gpu: bool = False,
         registry: str = None,
         base_image: str = None,
+        python_version: str = None,
     ) -> tuple[str, str]:
         """构建Docker镜像
 
@@ -511,6 +540,7 @@ def get_miniconda3_version(self) -> str:
             use_gpu: 是否使用GPU支持
             registry: 镜像仓库前缀
             base_image: 完整的基础镜像名
+            python_version: 指定的Python版本
 
         Returns:
             tuple: (image_name, image_id)
@@ -536,7 +566,7 @@ def get_miniconda3_version(self) -> str:
 
         # 生成Dockerfile
         dockerfile_content = self.generate_dockerfile(
-            project_path, has_examples, use_gpu, registry, base_image
+            project_path, has_examples, use_gpu, registry, base_image, python_version
         )
         dockerfile_path = project_path / "Dockerfile.inoyb"
 
